@@ -6,7 +6,7 @@
 // [[Rcpp::plugins(cpp11)]
 // [[Rcpp::depends(RcppArmadillo)]]
 
-Rcpp::CharacterVector as_character(const Rcpp::RObject vec);
-Rcpp::S4 brick(const Rcpp::S4 &raster);
+extern Rcpp::CharacterVector as_character(const Rcpp::RObject vec);
+extern Rcpp::S4 brick(const Rcpp::S4 &raster);
 
 #endif
